@@ -14,12 +14,14 @@ func NewGinkgoLinter(cfg *config.GinkgoLinterSettings) *goanalysis.Linter {
 	cfgMap := make(map[string]map[string]any)
 	if cfg != nil {
 		cfgMap[a.Name] = map[string]any{
-			"suppress-len-assertion":     cfg.SuppressLenAssertion,
-			"suppress-nil-assertion":     cfg.SuppressNilAssertion,
-			"suppress-err-assertion":     cfg.SuppressErrAssertion,
-			"suppress-compare-assertion": cfg.SuppressCompareAssertion,
-			"suppress-async-assertion":   cfg.SuppressAsyncAssertion,
-			"allow-havelen-0":            cfg.AllowHaveLenZero,
+			"suppress-len-assertion":          cfg.SuppressLenAssertion,
+			"suppress-nil-assertion":          cfg.SuppressNilAssertion,
+			"suppress-err-assertion":          cfg.SuppressErrAssertion,
+			"suppress-compare-assertion":      cfg.SuppressCompareAssertion,
+			"suppress-async-assertion":        cfg.SuppressAsyncAssertion,
+			"suppress-type-compare-assertion": cfg.SuppressTypeCompareWarning,
+			"forbid-focus-container":          cfg.ForbidFocusContainer,
+			"allow-havelen-0":                 cfg.AllowHaveLenZero,
 		}
 	}
 
