@@ -2,7 +2,6 @@ package printers
 
 import (
 	"bytes"
-	"context"
 	"go/token"
 	"strings"
 	"testing"
@@ -47,7 +46,7 @@ func TestCheckstyle_Print(t *testing.T) {
 	buf := new(bytes.Buffer)
 	printer := NewCheckstyle(buf)
 
-	err := printer.Print(context.Background(), issues)
+	err := printer.Print(issues)
 	require.NoError(t, err)
 
 	//nolint:lll
