@@ -2,10 +2,7 @@ package main
 
 import (
 	"bytes"
-	"crypto/sha256"
-	"encoding/hex"
 	"encoding/json"
-	"flag"
 	"fmt"
 	"io"
 	"log"
@@ -16,6 +13,8 @@ import (
 	"reflect"
 	"sort"
 	"strings"
+	"unicode"
+	"unicode/utf8"
 
 	"gopkg.in/yaml.v3"
 
@@ -27,49 +26,17 @@ import (
 
 const listItemPrefix = "list-item-"
 
-var stateFilePath = filepath.Join("docs", "template_data.state")
-
 func main() {
-	var onlyWriteState bool
-	flag.BoolVar(&onlyWriteState, "only-state", false, fmt.Sprintf("Only write hash of state to %s and exit", stateFilePath))
-	flag.Parse()
-
 	replacements, err := buildTemplateContext()
 	if err != nil {
 		log.Fatalf("Failed to build template context: %s", err)
 	}
 
-	if err = updateStateFile(replacements); err != nil {
-		log.Fatalf("Failed to update state file: %s", err)
-	}
-
-	if onlyWriteState {
-		return
-	}
-
 	if err := rewriteDocs(replacements); err != nil {
 		log.Fatalf("Failed to rewrite docs: %s", err)
 	}
-	log.Printf("Successfully expanded templates")
-}
 
-func updateStateFile(replacements map[string]string) error {
-	replBytes, err := json.Marshal(replacements)
-	if err != nil {
-		return fmt.Errorf("failed to json marshal replacements: %w", err)
-	}
-
-	h := sha256.New()
-	if _, err := h.Write(replBytes); err != nil {
-		return err
-	}
-
-	var contentBuf bytes.Buffer
-	contentBuf.WriteString("This file stores hash of website templates to trigger " +
-		"Netlify rebuild when something changes, e.g. new linter is added.\n")
-	contentBuf.WriteString(hex.EncodeToString(h.Sum(nil)))
-
-	return renameio.WriteFile(stateFilePath, contentBuf.Bytes(), os.ModePerm)
+	log.Print("Successfully expanded templates")
 }
 
 func rewriteDocs(replacements map[string]string) error {
@@ -137,7 +104,7 @@ type latestRelease struct {
 }
 
 func getLatestVersion() (string, error) {
-	req, err := http.NewRequest( // nolint:noctx
+	req, err := http.NewRequest( //nolint:noctx
 		http.MethodGet,
 		"https://api.github.com/repos/golangci/golangci-lint/releases/latest",
 		http.NoBody,
@@ -212,6 +179,7 @@ func buildTemplateContext() (map[string]string, error) {
 		"LintersCommandOutputDisabledOnly": string(lintersOutParts[1]),
 		"EnabledByDefaultLinters":          getLintersListMarkdown(true),
 		"DisabledByDefaultLinters":         getLintersListMarkdown(false),
+		"DefaultExclusions":                getDefaultExclusions(),
 		"ThanksList":                       getThanksList(),
 		"RunHelpText":                      string(shortHelp),
 		"ChangeLog":                        string(changeLog),
@@ -219,10 +187,29 @@ func buildTemplateContext() (map[string]string, error) {
 	}, nil
 }
 
+func getDefaultExclusions() string {
+	bufferString := bytes.NewBufferString("")
+
+	for _, pattern := range config.DefaultExcludePatterns {
+		_, _ = fmt.Fprintln(bufferString)
+		_, _ = fmt.Fprintf(bufferString, "### %s\n", pattern.ID)
+		_, _ = fmt.Fprintln(bufferString)
+		_, _ = fmt.Fprintf(bufferString, "- linter: `%s`\n", pattern.Linter)
+		_, _ = fmt.Fprintf(bufferString, "- pattern: `%s`\n", strings.ReplaceAll(pattern.Pattern, "`", "&grave;"))
+		_, _ = fmt.Fprintf(bufferString, "- why: %s\n", pattern.Why)
+	}
+
+	return bufferString.String()
+}
+
 func getLintersListMarkdown(enabled bool) string {
 	var neededLcs []*linter.Config
 	lcs := lintersdb.NewManager(nil, nil).GetAllSupportedLinterConfigs()
 	for _, lc := range lcs {
+		if lc.Internal {
+			continue
+		}
+
 		if lc.EnabledByDefault == enabled {
 			neededLcs = append(neededLcs, lc)
 		}
@@ -283,7 +270,20 @@ func getDesc(lc *linter.Config) string {
 		}
 	}
 
-	return strings.ReplaceAll(desc, "\n", "<br/>")
+	return formatDesc(desc)
+}
+
+func formatDesc(desc string) string {
+	runes := []rune(desc)
+
+	r, _ := utf8.DecodeRuneInString(desc)
+	runes[0] = unicode.ToUpper(r)
+
+	if runes[len(runes)-1] != '.' {
+		runes = append(runes, '.')
+	}
+
+	return strings.ReplaceAll(string(runes), "\n", "<br/>")
 }
 
 func check(b bool, title string) string {
@@ -313,34 +313,83 @@ func spanWithID(id, title, icon string) string {
 	return fmt.Sprintf(`<span id=%q title=%q>%s</span>`, id, title, icon)
 }
 
+type authorDetails struct {
+	Linters []string
+	Profile string
+	Avatar  string
+}
+
 func getThanksList() string {
-	var lines []string
-	addedAuthors := map[string]bool{}
+	addedAuthors := map[string]*authorDetails{}
+
 	for _, lc := range lintersdb.NewManager(nil, nil).GetAllSupportedLinterConfigs() {
+		if lc.Internal {
+			continue
+		}
+
 		if lc.OriginalURL == "" {
 			continue
 		}
 
-		const githubPrefix = "https://github.com/"
-		if !strings.HasPrefix(lc.OriginalURL, githubPrefix) {
-			continue
+		linterURL := lc.OriginalURL
+		if lc.Name() == "staticcheck" {
+			linterURL = "https://github.com/dominikh/go-tools"
 		}
 
-		githubSuffix := strings.TrimPrefix(lc.OriginalURL, githubPrefix)
-		githubAuthor := strings.Split(githubSuffix, "/")[0]
-		if addedAuthors[githubAuthor] {
+		if author := extractAuthor(linterURL, "https://github.com/"); author != "" && author != "golangci" {
+			if _, ok := addedAuthors[author]; ok {
+				addedAuthors[author].Linters = append(addedAuthors[author].Linters, lc.Name())
+			} else {
+				addedAuthors[author] = &authorDetails{
+					Linters: []string{lc.Name()},
+					Profile: fmt.Sprintf("[%[1]s](https://github.com/sponsors/%[1]s)", author),
+					Avatar:  fmt.Sprintf(`<img src="https://github.com/%[1]s.png" alt="%[1]s" style="max-width: 100%%;" width="20px;" />`, author),
+				}
+			}
+		} else if author := extractAuthor(linterURL, "https://gitlab.com/"); author != "" {
+			if _, ok := addedAuthors[author]; ok {
+				addedAuthors[author].Linters = append(addedAuthors[author].Linters, lc.Name())
+			} else {
+				addedAuthors[author] = &authorDetails{
+					Linters: []string{lc.Name()},
+					Profile: fmt.Sprintf("[%[1]s](https://gitlab.com/%[1]s)", author),
+				}
+			}
+		} else {
 			continue
 		}
-		addedAuthors[githubAuthor] = true
+	}
 
-		line := fmt.Sprintf("- [%s](https://github.com/%s)",
-			githubAuthor, githubAuthor)
-		lines = append(lines, line)
+	var authors []string
+	for author := range addedAuthors {
+		authors = append(authors, author)
+	}
+
+	sort.Slice(authors, func(i, j int) bool {
+		return strings.ToLower(authors[i]) < strings.ToLower(authors[j])
+	})
+
+	lines := []string{
+		"|Author|Linter(s)|",
+		"|---|---|",
+	}
+
+	for _, author := range authors {
+		lines = append(lines, fmt.Sprintf("|%s %s|%s|",
+			addedAuthors[author].Avatar, addedAuthors[author].Profile, strings.Join(addedAuthors[author].Linters, ", ")))
 	}
 
 	return strings.Join(lines, "\n")
 }
 
+func extractAuthor(originalURL, prefix string) string {
+	if !strings.HasPrefix(originalURL, prefix) {
+		return ""
+	}
+
+	return strings.SplitN(strings.TrimPrefix(originalURL, prefix), "/", 2)[0]
+}
+
 type SettingSnippets struct {
 	ConfigurationFile string
 	LintersSettings   string
@@ -404,7 +453,7 @@ func extractExampleSnippets(example []byte) (*SettingSnippets, error) {
 		globalNode.Content = append(globalNode.Content, node, newNode)
 
 		if node.Value == "linters-settings" {
-			snippets.LintersSettings, err = getLintersSettingSnippets(node, nextNode)
+			snippets.LintersSettings, err = getLintersSettingSections(node, nextNode)
 			if err != nil {
 				return nil, err
 			}
@@ -444,7 +493,19 @@ func extractExampleSnippets(example []byte) (*SettingSnippets, error) {
 	return &snippets, nil
 }
 
-func getLintersSettingSnippets(node, nextNode *yaml.Node) (string, error) {
+func getLintersSettingSections(node, nextNode *yaml.Node) (string, error) {
+	lcs := lintersdb.NewManager(nil, nil).GetAllSupportedLinterConfigs()
+
+	var lintersDesc = make(map[string]string)
+	for _, lc := range lcs {
+		if lc.Internal {
+			continue
+		}
+
+		// it's important to use lc.Name() nor name because name can be alias
+		lintersDesc[lc.Name()] = getDesc(lc)
+	}
+
 	builder := &strings.Builder{}
 
 	for i := 0; i < len(nextNode.Content); i += 2 {
@@ -466,6 +527,7 @@ func getLintersSettingSnippets(node, nextNode *yaml.Node) (string, error) {
 		}
 
 		_, _ = fmt.Fprintf(builder, "### %s\n\n", nextNode.Content[i].Value)
+		_, _ = fmt.Fprintf(builder, "%s\n\n", lintersDesc[nextNode.Content[i].Value])
 		_, _ = fmt.Fprintln(builder, "```yaml")
 
 		encoder := yaml.NewEncoder(builder)
