@@ -9,20 +9,18 @@ import (
 
 // builtin functions:
 func musttagJSONCustom() {
-	var user struct { // want `exported fields should be annotated with the "json" tag`
+	var user struct { // want "`anonymous struct` should be annotated with the `json` tag as it is passed to `json.Marshal` at "
 		Name  string
 		Email string `json:"email"`
 	}
 	json.Marshal(user)
-	json.Unmarshal(nil, &user)
 }
 
 // custom functions from config:
 func musttagASN1Custom() {
-	var user struct { // want `exported fields should be annotated with the "asn1" tag`
+	var user struct { // want "`anonymous struct` should be annotated with the `asn1` tag as it is passed to `asn1.Marshal` at "
 		Name  string
 		Email string `asn1:"email"`
 	}
 	asn1.Marshal(user)
-	asn1.Unmarshal(nil, &user)
 }
